#!/bin/sh
#creates a file containing a ext3 binary blob of the content of the ./rootfs folder

Usage()
{
	echo "creates a file containing a ext3 binary blob. File name is APP.ext3"
	echo "Usage: genext3fs.sh [OPTION]... dest_file_name"
	echo "-h : Prints this message"
	echo "-b : Sets the partition size in MBytes, default 256"
	echo "-d : Selects the directory which contains the partition content, default ../rootfs"
	echo ""
}

PARTITIONSIZE=256
SRCPATH=../rootfs

while getopts "b:d:h" Option ; do
	case $Option in
		h) Usage
			# Exit if only usage (-h) was specfied.
			if [[ $# -eq 1 ]] ; then
				exit 10
			fi
			exit 0
			;;
		b) PARTITIONSIZE=$OPTARG
			;;
		d) SRCPATH=$OPTARG
			;;
	esac
done
#adjust the commandline arg for the now used options
shift $(($OPTIND - 1))

#create the file used for the loopbackdevice and format it for ext3
#answer y to "is not a block special device"
dd if=/dev/zero of=$@ bs=1024k count=$PARTITIONSIZE
mkfs.ext3 -F -L arm $@ 

#mount the file as a loopdevice 
sudo mkdir -p mnt/rootfs
sudo umount mnt/rootfs &> /dev/null
sudo mount $@ mnt/rootfs/ -o loop -t ext3

#extract rootfs into the file
sudo cp -rpP $SRCPATH/* mnt/rootfs

#unmount again
sudo umount mnt/rootfs

